/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:21+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Either postalcode or postbox is required!"
: "Bitte geben Sie entweder eine Postleitzahl oder ein Postfach an!"

, "Copy Supplier"
: "Lieferant kopieren"

, "Add New Supplier"
: "Neuen Lieferant hinzufügen"

, "Edit Supplier \"{0}\""
: "Lieferant \"{0}\" bearbeiten"

, "Copy address to the clipboard"
: "Adresse in die Zwischenablage kopieren"

, "Supplier, Suppliers"
: [
  "Lieferant"
 ,"Lieferanten"

]
, "Core Data"
: "Stammdaten"

, "Supplier Number"
: "Lieferantennummer"

, "Name"
: "Name"

, "Contact Person (external)"
: "Kontaktperson (extern)"

, "Contact Person (internal)"
: "Kontaktperson (intern)"

, "Accounting"
: "Abrechnung"

, "VAT ID"
: "USt.-ID"

, "Credit Term (days)"
: "Zahlungsziel in Tagen"

, "Currency"
: "Währung"

, "Currency Translation Rate"
: "Wechselkurs"

, "IBAN"
: "IBAN"

, "BIC"
: "BIC"

, "Postal Address"
: "Postanschrift"

, "Street"
: "Straße"

, "Postbox"
: "Postfach"

, "Postalcode"
: "Postleitzahl"

, "Locality"
: "Ort"

, "Region"
: "Region"

, "Country"
: "Land"

, "Prefix"
: "Zusatz"

, "Additional Prefix"
: "Zusatz 2"

, "Miscellaneous"
: "Sonstiges"

, "Web"
: "Internet"

, "Description"
: "Beschreibung"

, "Enter description"
: "Bitte geben Sie eine Beschreibung an"

, "total"
: "Gesamtsumme"

, "inclusive"
: "Inklusive"

, "exceeding"
: "Überschreitet"

, "Create timesheet"
: "Timesheet erstellen"

, "Create Reversal Invoice"
: "Storno-Rechnung erstellen"

, "Copy Invoice"
: "Rechnung kopieren"

, "Add New Invoice"
: "Neue Rechnung hinzufügen"

, "Edit Invoice \"{0}\""
: "Rechnung \"{0}\" bearbeiten"

, "Positions ({0})"
: "Position ({0})"

, "No customer assigned"
: "Kein Kunde zugeordnet"

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: "Dem ausgewählten Vertrag ist bisher kein Kunde zugeordnet worden. Bitte verknüpfen Sie den Vertrag mit einem Kunden."

, "No cost center assigned"
: "Keine Kostenstelle zugeordnet"

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: "Dem ausgewählten Vertrag ist bisher keine Kostenstelle zugeordnet worden. Bitte verknüpfen Sie den Vertrag mit einer Kostenstelle."

, "Price Net"
: "Nettopreis"

, "Taxes (VAT)"
: "MwSt"

, "Price Gross"
: "Bruttopreis"

, "Sales Tax (percent)"
: "MwSt. in Prozent"

, "Inventory Change"
: "Bestandsänderung"

, "Invoice, Invoices"
: [
  "Rechnung"
 ,"Rechnungen"

]
, "Invoice Number"
: "Rechnungsnummer"

, "automatically set..."
: "automatisch ausgefüllt..."

, "Date"
: "Datum"

, "Type"
: "Typ"

, "Contract, Contracts"
: [
  "Vertrag"
 ,"Verträge"

]
, "Customer, Customers"
: [
  "Kunde"
 ,"Kunden"

]
, "Billing Address"
: "Rechnungsanschrift"

, "Credit Term"
: "Zahlungsziel in Tagen"

, "Cleared"
: "Gebucht"

, "Interval Begins"
: "Buchungszeitraum Beginn"

, "Interval Ends"
: "Buchungszeitraum Ende"

, "Select invoice"
: "Rechnung auswählen"

, "Total Price"
: "Gesamtpreis"

, "Cancel"
: "Abbrechen"

, "OK"
: "OK"

, "Loading..."
: "Lade ..."

, "Euro (€)"
: "Euro (€)"

, "Order Confirmation, Order Confirmations"
: [
  "Auftragsbestätigung"
 ,"Auftragsbestätigungen"

]
, "without order confirmation"
: "ohne Auftragsbestätigung"

, "Number"
: "Nummer"

, "Title"
: "Titel"

, "Billing Addresses"
: "Rechnungsanschriften"

, "Delivery Address"
: "Lieferanschrift"

, "Delivery Addresses"
: "Lieferanschriften"

, "Edit {0} \"{1}\""
: "{0} \"{1}\" bearbeiten"

, "Add New Billing Address"
: "Neue Rechnungsanschrift Hinzufügen"

, "Add New Delivery Address"
: "Neue Lieferanschrift Hinzufügen"

, "Apply postal address"
: "Postanschrift anwenden"

, "Number Debit"
: "Debitorennummer"

, "Address, Addresss"
: [
  "Anschrift"
 ,"Anschriften"

]
, "without customer"
: "ohne Kunde"

, "Copy Purchase Invoice"
: "Eingangsrechnung kopieren"

, "Add New Purchase Invoice"
: "Neue Eingangsrechnung hinzufügen"

, "Edit Purchase Invoice \"{0}\""
: "Eingangsrechnung \"{0}\" bearbeiten"

, "Date of invoice"
: "Rechnungsdatum"

, "Due in"
: "Fällig in"

, "Due date"
: "Fälligkeitsdatum"

, "Additional Price Gross"
: "Zusätzlicher Bruttopreis"

, "Discount (%)"
: "Rabatt in Prozent"

, "Purchase Invoice, Purchase Invoices"
: [
  "Eingangsrechnung"
 ,"Eingangsrechnungen"

]
, "Overdue date"
: "Überfälligkeits Datum"

, "Discount until"
: "Skonto bis"

, "Dun date"
: "Mahnungsdatum"

, "Payed at"
: "Gezahlt am"

, "Method of payment"
: "Zahlungsart"

, "Approver"
: "Genehmigt von"

, "Lead Cost Center"
: "Hauptkostenstelle"

, "Add New Offer"
: "Neues Angebot hinzufügen"

, "Clipboard"
: "Zwischenablage"

, "Product, Products"
: [
  "Produkt"
 ,"Produkte"

]
, "Quantity"
: "Anzahl"

, "Interval"
: "Intervall"

, "Billing Point"
: "Abrechnungszeitpunkt"

, "begin"
: "Anfang des Intervalls"

, "end"
: "Ende des Intervalls"

, "Start Date"
: "Anfang"

, "End Date"
: "Ende"

, "Attributes"
: ""

, "Last Autobill"
: "Zuletzt Abgerechnet"

, "Creation Time"
: "Angelegt am"

, "Created By"
: "Angelegt von"

, "Last Modified Time"
: "Letztes Modifikationsdatum"

, "Last Modified By"
: "Zuletzt geändert von"

, "Edit Attributes"
: "Attribute bearbeiten"

, "Attribute"
: "Attribute"

, "Value"
: "Wert"

, "Add a New Value..."
: "Neuen Wert hinzufügen ..."

, "without contract"
: "ohne Vertrag"

, "Add New Order Confirmation"
: "Neue Auftragsbestätigung hinzufügen"

, "Offer, Offers"
: [
  "Angebot"
 ,"Angebote"

]
, "Add New Product"
: "Neues Produkt hinzufügen"

, "Product Number"
: "Produktnummer"

, "GTIN"
: "GTIN"

, "Category"
: "Kategorie"

, "Manufacturer"
: "Hersteller"

, "Purchaseprice"
: "Einkaufspreis"

, "Salesprice"
: "Verkaufspreis"

, "Lifespan start"
: "Laufzeit Beginn"

, "Lifespan end"
: "Laufzeit Ende"

, "Enter description..."
: "Bitte geben Sie eine Beschreibung ein..."

, "Accountable"
: "Rechnet ab"

, "Selected  {0}"
: "{0} ausgewählt"

, "Select customer"
: "Kunden auswählen"

, "Customer Number"
: "Kundennummer"

, "Products"
: "Produkte"

, "Rebilling Invoice..."
: "Erzeuge Rechnung neu..."

, "Rebill Invoice"
: "Rechnung neu erzeugen"

, "Merge Invoices"
: "Rechnungen zusammenführen"

, "Select supplier"
: "Lieferant auswählen"

, "Add New Cost Center"
: "Neue Kostenstelle hinzufügen"

, "Remark"
: "Anmerkung"

, "without supplier"
: "ohne Lieferant"

, "Add New Division"
: "Neue Abteilung hinzufügen"

, "Bill Contract"
: "Vertrag abrechnen"

, "Billing Contract..."
: "Rechne Vertrag ab..."

, "Bill Contract \"{0} - {1}\""
: "Vertrag \"{0} - {1}\" abrechnen"

, "Select the date to generate the bill for"
: "Bitte wählen Sie das Datum, zu dem Sie die Rechnung erzeugen möchten"

, "Either street or postbox is required!"
: "Bitte geben Sie entweder eine Straße oder ein Postfach an!"

, "Copy Customer"
: "Kunden kopieren"

, "Add New Customer"
: "Neuen Kunden hinzufügen"

, "Edit Customer \"{0}\""
: "Kunden \"{0}\" bearbeiten"

, "Name shorthand"
: "Kunden Kürzel"

, "Set as accountable"
: "Als verantwortlich festlegen"

, "Choose product for accountable"
: "Wählen Sie das Produkt für verantwortlich"

, "Please use a decimal number here!"
: "Bitte benutzen Sie eine Dezimalzahl!"

, "Positions"
: "Positionen"

, "Ok"
: "Ok"

, "Export Records from these Positions"
: "Exportiere Einträge dieser Positionen"

, "without approver"
: "nicht genehmigt"

, "Auto Invoice Contract Interval"
: "Vertragsintervall automatisch abrechnen"

, "Sets the biggest interval, contracts will be billed."
: "Setze das größte Intervall, zu dem Verträge gebucht werden."

, "Ignore Billables Before Date"
: "Abrechenbares vor Datum ignorieren"

, "Sets the date billables will be ignored before."
: "Setze Datum, bis zu dem Abrechnbares ignoriert wird."

, "Contract Number Creation"
: "Vertragsnummer-Erstellung"

, "Should the contract number be set manually or be auto-created?"
: "Soll die Vertragsnummer manuell gesetzt oder autmatisch erstellt werden?"

, "automatically"
: "automatisch"

, "manually"
: "manuell"

, "Contract Number Validation"
: "Vertragsnummer-Validierung"

, "The Number can be validated as text or number."
: "Die Vertragsnummer kann als Text oder Nummer validiert werden."

, "Text"
: "Text"

, "Own Currency"
: "Eigene Währung"

, "The currency defined here is used as default currency in the customerd edit dialog."
: "Die hier definierte Währung wird als standard Währung für den Kunden bearbeiten Dialog verwendet."

, "Invoice Type"
: "Rechnungstyp"

, "Possible Invoice Types."
: "Mögliche Rechnungstypen."

, "Reversal"
: "Storno"

, "Credit"
: "Gutschrift"

, "Product Category"
: "Produktkategorie"

, "Possible Product Categories."
: "Mögliche Produktkategorien."

, "Default"
: "Default"

, "Product Number Creation"
: "Produktnummern Erstellung"

, "Should the product number be set manually or be auto-created?"
: "Soll die Produktnummer manuell oder automatisch erstellt werden?"

, "Product Number Validation"
: "Produktnummern Validation"

, "Product Number Prefix"
: "Produktnummern Präfix"

, "The prefix of the product number."
: "Das Präfix der Produktnummer."

, "Product Number Zero Fill"
: "Nummer mit führender Null auffüllen"

, "Fill the number with leading zero"
: "Nummer mit führender Null auffüllen"

, "Payment Method"
: "Zahlungsart"

, "Possible Payment Methods."
: "Mögliche Zahlungsarten"

, "Bank transfer"
: "Banküberweisung"

, "Direct debit"
: "Lastschrifteinzug"

, "Cancellation"
: "Stornierung"

, "Credit card"
: "Kreditkarte"

, "EC card"
: "EC Karte"

, "Paypal"
: "Paypal"

, "Assets"
: "Guthaben"

, "Invoice Cleared"
: "Rechnung gebucht"

, "Possible Invoice Cleared States."
: "Mögliche Werte für Buchungsstatus"

, "to clear"
: "zu buchen"

, "cleared"
: "gebucht"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Sales Application."
: "Feature in der Sales Applikation aktivieren."

, "Invoices Module"
: "Rechnungsmodul"

, "Offers Module"
: "Angebotsmodul"

, "Order Confirmations Module"
: "Auftragsbestätigung Modul"

, "Suppliers Module"
: "Lieferantenmodul"

, "Purchase Invoice Module"
: "Eingangsrechnungsmodul"

, "You do not have admin rights on Sales"
: "Sie haben kein Adminrecht in der Sales-Applikation"

, "Number duplicate"
: "Mehrfach vergebene Nummer"

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: "Die Nummer die Sie für diesen Datensatz verwenden wollten, ist bereits vergeben. Bitte versuchen Sie es mit einer anderen, oder lassen das Feld leer, um die nächst freie Nummer zu verwenden."

, "Following Invoices Found"
: "Nachfolgende Rechnungen gefunden"

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: "Es existiert bereits eine spätere Rechnung für den selben Vertrag. Bitte löschen Sie die spätere(n) Rechnung(en), bevor Sie diese Rechnung löschen!"

, "Address as Billing Address in Use"
: "Adresse als Rechnungsadresse in Benutzung"

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: "Die Adresse, die Sie löschen wollten, ist bei einem oder mehreren Verträgen als Rechnungsadresse gesetzt. Bitte weisen Sie den Verträgen eine andere Rechnungsadresse zu oder verändern Sie diese, ohne sie zu löschen."

, "Invoice is cleared already"
: "Rechnung ist bereits gebucht"

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: "Die Rechnung die Sie löschen wollten, ist bereits gebucht und kann nicht mehr gelöscht werden!"

, "No Right to alter the Number"
: "Keine Berechtigung die Nummer zu verändern"

, "You are not allowed to alter the number afterwards!"
: "Die Nummer kann nachträglich nicht mehr geändert werden!"

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: "Die Rechnung die Sie bearbeiten wollten, ist bereits gebucht und kann nicht weiter bearbeitet werden!"

, "Unknown Currency Code"
: "Unbekannter Währungscode"

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: "Der Währungscode, den Sie versucht haben, einzugeben, ist nicht gültig. Bitte verwenden Sie einen gültigen Währungscode nach ISO 4217."

, "Invoice Timesheet"
: "Rechnungs Timesheet"

, "CLEARED"
: "GEBUCHT"

, "INVOICE"
: "RECHNUNG"

, "GENDER_Cost Center"
: "female"

, "Cost Center, Cost Centers"
: [
  "Kostenstelle"
 ,"Kostenstellen"

]
, "GENDER_Offer"
: "other"

, "GENDER_Invoice"
: "female"

, "Sales Tax"
: "Mehrwertsteuer"

, "Reversal Invoice"
: "Storno-Rechnung"

, "Invoice Item"
: "Rechnungsposten"

, "Is active"
: "Ist aktiv"

, "GENDER_Contract"
: "male"

, "Merge"
: "Zusammenführen"

, "Responsible"
: "Verantwortlicher"

, "Partner"
: "Partner"

, "Time Account"
: "Zeitkonto"

, "GENDER_Customer)recordsName"
: ""

, "GENDER_Order Confirmation"
: ""

, "GENDER_Supplier"
: ""

, "GENDER_Division"
: "female"

, "Division, Divisions"
: [
  "Abteilung"
 ,"Abteilung"

]
, "Billing Interval"
: "Mtl. Abrechnungsintervall (variabel)"

, "Piece"
: "Stück"

, "GENDER_Address"
: "female"

, "Due at"
: "Fällig am"

, "Invoice Position, Invoice Positions"
: [
  "Rechnungsposition"
 ,"Rechnungspositionen"

]
, "Month"
: "Monat"

, "Unit"
: "Einheit"

, "The number you have tried to set is already in use!"
: "Diese Nummer ist bereits vergeben!"

, "My Products"
: "Meine Produkte"

, "Products created by me"
: "Produktdatensätze, die ich angelegt habe"

, "My Contracts"
: "Meine Verträge"

, "Contracts created by myself"
: "Von mir erstellte Aufträge"

, "All Customers"
: "Alle Kunden"

, "All customer records"
: "Datensätze aller Kunden"

, "All Offers"
: "Alle Angebotsdatensätze"

, "All offer records"
: "Alle Angebote"

, "Inactive Contracts"
: "Inaktive Verträge"

, "Contracts that have already been terminated"
: "Verträge die bereits gekündigt sind"

, "Active Contracts"
: "Aktive Verträge"

, "Contracts that are still running"
: "Verträge die noch am laufen sind"

, "All Suppliers"
: "Alle Lieferanten"

, "All supllier records"
: "Alle Lieferantendatensätze"

, "All Purchase Imvoices"
: "Alle Eingangsrechnungen"

, "All purchase invoices"
: "Alle Eingangsrechnungen"

, "All Products"
: "Alle Produkte"

, "All product records"
: "Alle Produktdatensätze"

, "All Contracts"
: "Alle Verträge"

, "All contract records"
: "Alle Vertragsdatensätze"

, "All Invoices"
: "Alle Rechnungen"

, "All invoice records"
: "Alle Rechnungsdatensätze"

, "All Cost Centers"
: "Alle Kostenstellen"

, "All costcenter records"
: "Alle Kostenstellendatensätze"

, "All Divisions"
: "Alle Abteilungen"

, "All division records"
: "Alle Abteilungsdatensätze"

, "All Order Confirmations"
: "Alle Auftragsbestätigungen"

, "All order confirmation records"
: "Alle Auftragsbestätigungsdatensätze"

, "You have to set a customer!"
: "Bitte legen Seien Kunden fest."

, "Manage Products"
: "Produkte Verwalten"

, "Add, edit and delete products."
: "Hinzufügen, editieren und löschen von Produkten."

, "Manage Contracts"
: "Verträge Verwalten"

, "Add, edit and delete contracts."
: "Verträge hinzufügen, bearbeiten und löschen."

, "Manage Cost Centers"
: "Kostenstellen Verwalten"

, "Add, edit and delete cost centers."
: "Kostenstellen hinzufügen, bearbeiten und löschen."

, "Manage Customers"
: "Kunden Verwalten"

, "Add, edit and delete customers."
: "Kunden hinzufügen, bearbeiten und löschen."

, "Manage Suppliers"
: "Lieferanten Verwalten"

, "Add, edit and delete suppliers."
: "Lieferanten hinzufügen, editieren oder entfernen."

, "manage invoices"
: "Rechungen verwalten"

, "Add, edit and delete invoices."
: "Rechnungen hinzufügen, bearbeiten und löschen."

, "Manage Divisions"
: "Abteilungen Verwalten"

, "Add, edit and delete divisions."
: "Abteilungen hinzufügen, bearbeiten und löschen."

, "Manage Order Confirmations"
: "Auftragsbestätigungen Verwalten"

, "Add, edit and delete order confirmations."
: "Auftragsbestätigungen hinzufügen, bearbeiten und löschen."

, "Manage Offers"
: "Angebote Verwalten"

, "Add, edit and delete offers."
: "Angebote hinzufügen, bearbeiten und löschen."

, "Manage Purchase Invoices"
: "Eingangsrechnungen Verwalten"

, "Add, edit and delete purchase invoices."
: "Eingangsrechnungen hinzufügen, editieren oder entfernen."

, "Change number of an order confirmations"
: "Nummer einer Auftragsbestätigung ändern"

, "Allow changing the number of an order confirmation during the update."
: "Änderung der Nummer einer Auftragsbestätigung beim Update erlauben."

, "Set number of invoices"
: "Rechnungsnummer manuell vergeben."

, "Allow to set the number of an invoice."
: "Erlaubt, die Rechnungsnummer manuell zu vergeben."





































, "Supplier"
: "Lieferant"

, "Invoice"
: "Rechnung"

, "Contract"
: "Vertrag"

, "Customer"
: "Kunde"

, "Order Confirmation"
: "Auftragsbestätigung"

, "Address"
: "Anschrift"

, "Purchase Invoice"
: "Eingangsrechnung"

, "Product"
: "Produkt"

, "Offer"
: "Angebot"

, "Cost Center"
: "Kostenstelle"

, "Division"
: "Abteilung"

, "Invoice Position"
: "Rechnungsposition"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
